/// <reference types="react" />

import Ajv from 'ajv';
import { ArrayControlProps } from '@jsonforms/core';
import type { CellProps } from '@jsonforms/core';
import { CombinatorKeyword } from '@jsonforms/core';
import type { ComponentType } from 'react';
import { DispatchPropsOfControl } from '@jsonforms/core';
import type { DispatchPropsOfMultiEnumControl } from '@jsonforms/core';
import type { EnumCellProps } from '@jsonforms/core';
import { FunctionComponent } from 'react';
import { JsonSchema } from '@jsonforms/core';
import type { JSX as JSX_2 } from 'react/jsx-runtime';
import type { LayoutProps } from '@jsonforms/core';
import type { OwnPropsOfCell } from '@jsonforms/core';
import { OwnPropsOfControl } from '@jsonforms/core';
import type { OwnPropsOfEnum } from '@jsonforms/core';
import type { OwnPropsOfEnumCell } from '@jsonforms/core';
import type { OwnPropsOfLayout } from '@jsonforms/core';
import { RankedTester } from '@jsonforms/core';
import { default as React_2 } from 'react';
import * as React_3 from 'react';
import { ReactNode } from 'react';
import type { StatePropsOfLayout } from '@jsonforms/core';

/**
 * The props for ajv.
 */
declare interface AjvProps {
    ajv: Ajv;
}

export declare const allCopiesUpdater: (jsonPath: string, newData: unknown) => (data: unknown) => unknown;

declare interface AnimationWrapperProps {
    children?: React.ReactNode;
    elements?: JSX.Element;
    enableDetailedView?: boolean;
    expanded: boolean;
    setExpanded: (desiredState: boolean, usesDetailedView: boolean) => void;
    header?: JSX.Element;
    isAnimating: boolean;
    path: string;
    setIsAnimating: (isAnimating: boolean) => void;
}

export declare const areEqual: (prevProps: object | JsonSchema | undefined, nextProps: object | JsonSchema | undefined) => boolean;

export declare class Breadcrumbs {
    #private;
    constructor(data?: NamedBreadcrumb[]);
    get(path: string): {
        name: string | null;
        usesDetailedView: boolean;
    } | undefined;
    addBreadcrumb({ path, name, crxPath, usesDetailedView }: NamedBreadcrumb): Breadcrumbs;
    deleteBreadcrumb(path: string): Breadcrumbs;
    truncateBreadcrumbsAtParent(path: string): Breadcrumbs;
    truncateBreadcrumbsAndDelete(path: string): Breadcrumbs;
    truncateBreadcrumbsAndAdd(path: string): Breadcrumbs;
    truncateBreadcrumbs(path: string): Breadcrumbs;
    leavePrefixesOnly(path: string): Breadcrumbs;
    clear(): Breadcrumbs;
    hasPrefix(path: string): boolean;
    has(path: string): boolean;
    keys(): string[];
    entries(): [string, {
        name: string | null;
        usesDetailedView: boolean;
    }][];
    optimisticLongestPath(): string | undefined;
}

export declare const BreadcrumbsContext: React_2.Context<BreadcrumbsContextType>;

/**
 * The props of the BreadCrumbsContext.
 */
declare interface BreadcrumbsContextType {
    breadcrumbs: Breadcrumbs;
    addBreadcrumb: (breadcrumb: NamedBreadcrumb) => void;
    deleteBreadcrumb: (path: string) => void;
    truncateBreadcrumbs: (path: string) => void;
    truncateBreadcrumbsAtParent: (path: string) => void;
    truncateBreadcrumbsAndDelete: (path: string) => void;
    truncateBreadcrumbsAndAdd: (path: string) => void;
    resetBreadcrumbs: (data: NamedBreadcrumb[]) => void;
}

export declare const BreadcrumbsProvider: ({ children }: {
    children: React_2.ReactNode;
}) => JSX_2.Element;

export declare function checkIfUserIsOnMobileDevice($userAgent: any): boolean;

export declare const circularReferenceReplacer: () => (this: Object, field: string, value: any) => any;

export declare const cssToObject: (cssString: string) => any;

declare namespace Customizable {
    export {
        SpectrumBooleanButtonCell_2 as SpectrumBooleanButtonCell,
        SpectrumBooleanCell_2 as SpectrumBooleanCell,
        SpectrumCheckboxCell_2 as SpectrumCheckboxCell,
        SpectrumEnumCell_2 as SpectrumEnumCell,
        SpectrumIntegerCell_2 as SpectrumIntegerCell,
        SpectrumNumberCell_2 as SpectrumNumberCell,
        SpectrumRatingCell,
        SpectrumSliderCell_2 as SpectrumSliderCell,
        SpectrumSwitchCell_2 as SpectrumSwitchCell,
        SpectrumTextAreaCell_2 as SpectrumTextAreaCell,
        SpectrumTextCell_2 as SpectrumTextCell
    }
}
export { Customizable }

export declare const dataTestId: (testId: string) => {
    'data-test-id': string;
} | {
    'data-test-id'?: undefined;
};

export declare function DeleteDialog({ cancelBtnText, confirmBtnText, contentText, deleteModalOpen, headingText, onPressEndHandler, onPressStartHandler, setDeleteModalOpen, }: DeleteDialogProps): JSX_2.Element;

declare interface DeleteDialogProps {
    cancelBtnText?: string;
    confirmBtnText?: string;
    contentText?: string;
    deleteModalOpen: boolean;
    headingText?: string;
    onPressEndHandler: () => void;
    onPressStartHandler: () => void;
    setDeleteModalOpen: (value: boolean) => void;
}

export declare class DetectKeyboardUser {
    constructor();
    init(): void;
    destroy(): void;
    refresh(): void;
}

export declare const ErrorIndicator: ({ errors }: {
    errors: React_2.ReactNode;
}) => JSX_2.Element;

export declare const findValue: any;

export declare const InputControl: ComponentType<OwnPropsOfControl>;

export declare const inputControlTester: RankedTester;

export declare function isEmpty(obj: any): boolean;

export declare const isISODate: (date: any) => boolean;

export declare const isValidCheck: (inputText: string, data: string | undefined, minLength: number, maxLength: number | undefined, isValid: boolean, customFormat: any, format: any) => boolean;

export declare const isValidPattern: (value: string, pattern: string) => boolean;

export declare const lengthErrorMessage: (minLength: number, maxLength: number | undefined) => string | undefined;

export declare function LoadingSpinner(): JSX_2.Element;

export declare const MediaPreviewControl: ComponentType<OwnPropsOfControl>;

export declare const MediaPreviewControlTester: RankedTester;

export declare const ModalItemAnimationWrapper: ({ children, elements, enableDetailedView, expanded, setExpanded, header, isAnimating, path, setIsAnimating, }: AnimationWrapperProps) => React_2.ReactPortal;

/**
 * The props of the BreadCrumb.
 */
declare interface NamedBreadcrumb {
    path: string;
    name: string | null;
    crxPath?: string;
    usesDetailedView?: boolean;
}

export declare const objectToCss: (cssObject: any) => string;

export declare const patternErrorMessage: (value: string, pattern: string | undefined, minLength: number, maxLength: number | undefined) => any;

export declare const RenderersConfigContextProvider: (props: RenderersConfigContextType & {
    children: ReactNode;
}) => JSX_2.Element;

declare interface RenderersConfigContextType {
    externalizePath?: (path: string) => string | undefined;
}

export declare const resolveSubSchemas: (schema: JsonSchema, rootSchema: JsonSchema, keyword: CombinatorKeyword) => JsonSchema;

export declare const settings: {
    toolTipDelay: number;
};

export declare const SpectrumAllOfRenderer: ComponentType<OwnPropsOfControl>;

export declare const SpectrumAllOfRendererTester: RankedTester;

export declare const SpectrumAnyOfRenderer: React_3.ComponentType<OwnPropsOfControl>;

export declare const SpectrumAnyOfRendererTester: RankedTester;

export declare const SpectrumAnyOfStringOrEnumControl: ComponentType<OwnPropsOfControl & OwnPropsOfEnum>;

export declare const SpectrumAnyOfStringOrEnumControlTester: RankedTester;

export declare const SpectrumArrayModalControl: React_2.ComponentType<OwnPropsOfControl>;

export declare const SpectrumArrayModalControlTester: RankedTester;

export declare const SpectrumBooleanButtonCell: ComponentType<OwnPropsOfCell>;

declare const SpectrumBooleanButtonCell_2: (props: CellProps & SpectrumInputProps) => JSX_2.Element;

/**
 * Default tester for BooleanButton controls.
 * @type {RankedTester}
 */
export declare const SpectrumBooleanButtonCellTester: RankedTester;

export declare const SpectrumBooleanButtonControl: ComponentType<OwnPropsOfControl>;

export declare const SpectrumBooleanButtonControlTester: RankedTester;

export declare const SpectrumBooleanCell: React_2.ComponentType<OwnPropsOfCell>;

declare const SpectrumBooleanCell_2: FunctionComponent<CellProps>;

/**
 * Default tester for boolean controls.
 * @type {RankedTester}
 */
export declare const SpectrumBooleanCellTester: RankedTester;

export declare const SpectrumBooleanControl: ComponentType<OwnPropsOfControl>;

export declare const SpectrumBooleanControlTester: RankedTester;

export declare const SpectrumCategorizationRenderer: ComponentType<StatePropsOfLayout & OwnPropsOfLayout>;

export declare const SpectrumCategorizationRendererTester: RankedTester;

export declare const SpectrumCategorizationStepperRenderer: React_2.ComponentType<StatePropsOfLayout & OwnPropsOfLayout>;

export declare const SpectrumCategorizationStepperRendererTester: RankedTester;

export declare const SpectrumCells: {
    tester: RankedTester;
    cell: any;
}[];

export declare const SpectrumCheckboxCell: ComponentType<OwnPropsOfCell>;

declare const SpectrumCheckboxCell_2: (props: CellProps & SpectrumInputProps) => JSX_2.Element;

/**
 * Default tester for checkbox controls.
 * @type {RankedTester}
 */
export declare const SpectrumCheckboxCellTester: RankedTester;

export declare const SpectrumCheckboxControl: ComponentType<OwnPropsOfControl>;

export declare const SpectrumCheckboxControlTester: RankedTester;

export declare const SpectrumCodeMirror: ComponentType<OwnPropsOfControl>;

export declare const SpectrumCodeMirrorTester: RankedTester;

export declare const SpectrumContentReferenceControl: React_2.ComponentType<OwnPropsOfControl>;

export declare const SpectrumContentReferenceControlTester: RankedTester;

export declare const SpectrumDateControl: ComponentType<OwnPropsOfControl>;

export declare const SpectrumDateControlTester: RankedTester;

export declare const SpectrumDateTimeControl: ComponentType<OwnPropsOfControl>;

export declare const SpectrumDateTimeControlTester: RankedTester;

export declare const SpectrumEnumCell: ComponentType<OwnPropsOfEnumCell>;

declare const SpectrumEnumCell_2: (props: EnumCellProps & SpectrumInputProps) => JSX_2.Element;

/**
 * Default tester for enum controls.
 * @type {RankedTester}
 */
export declare const SpectrumEnumCellTester: RankedTester;

export declare const SpectrumEnumControl: ComponentType<OwnPropsOfControl & OwnPropsOfEnum>;

export declare const SpectrumEnumControlTester: RankedTester;

export declare const SpectrumFragmentReferenceControl: React_2.ComponentType<OwnPropsOfControl>;

export declare const SpectrumFragmentReferenceControlTester: RankedTester;

export declare const SpectrumGroupLayout: React_2.ComponentType<LayoutProps & OwnPropsOfLayout>;

/**
 * Default tester for a group layout.
 *
 * @type {RankedTester}
 */
export declare const SpectrumGroupLayoutTester: RankedTester;

export declare const SpectrumHorizontalLayout: React_2.ComponentType<LayoutProps & OwnPropsOfLayout>;

/**
 * Default tester for a horizontal layout.
 * @type {RankedTester}
 */
export declare const SpectrumHorizontalLayoutTester: RankedTester;

/**
 * Additional props for Spectrum Input controls
 */
declare interface SpectrumInputProps {
    label?: string;
    required?: boolean;
    schema?: {
        [key: string]: any;
        readOnly?: boolean;
    };
}

export declare const SpectrumIntegerCell: ComponentType<OwnPropsOfCell>;

declare const SpectrumIntegerCell_2: (props: CellProps & SpectrumInputProps) => JSX_2.Element;

/**
 * Default tester for integer controls.
 * @type {RankedTester}
 */
export declare const SpectrumIntegerCellTester: RankedTester;

export declare const SpectrumIntegerControl: ComponentType<OwnPropsOfControl>;

export declare const SpectrumIntegerControlTester: RankedTester;

export declare const SpectrumLabelControl: ComponentType<OwnPropsOfControl>;

export declare const SpectrumLabelControlTester: RankedTester;

export declare const SpectrumLabelRenderer: React_2.ComponentType<LayoutProps & OwnPropsOfLayout>;

/**
 * Default tester for a label.
 * @type {RankedTester}
 */
export declare const SpectrumLabelRendererTester: RankedTester;

export declare const SpectrumListWithDetailRenderer: React_2.ComponentType<OwnPropsOfControl>;

export declare const SpectrumListWithDetailTester: RankedTester;

export declare const SpectrumMultiOneOfEnumControl: ComponentType<OwnPropsOfControl & OwnPropsOfEnum & DispatchPropsOfMultiEnumControl>;

export declare const SpectrumMultiOneOfEnumControlTester: RankedTester;

export declare const SpectrumNumberCell: ComponentType<OwnPropsOfCell>;

declare const SpectrumNumberCell_2: (props: CellProps) => JSX_2.Element;

/**
 * Default tester for number controls.
 * @type {RankedTester}
 */
export declare const SpectrumNumberCellTester: RankedTester;

export declare const SpectrumNumberControl: ComponentType<OwnPropsOfControl>;

export declare const SpectrumNumberControlTester: RankedTester;

export declare const SpectrumObjectControlTester: RankedTester;

export declare const SpectrumObjectRenderer: ComponentType<OwnPropsOfControl>;

export declare const SpectrumOneOfEnumControl: ComponentType<OwnPropsOfControl & OwnPropsOfEnum>;

export declare const SpectrumOneOfEnumControlTester: RankedTester;

export declare const SpectrumOneOfRadioGroupControl: ComponentType<OwnPropsOfControl & OwnPropsOfEnum>;

export declare const SpectrumOneOfRadioGroupControlTester: RankedTester;

export declare const SpectrumOneOfRenderer: React_2.ComponentType<OwnPropsOfControl>;

export declare const SpectrumOneOfRendererTester: RankedTester;

export declare const SpectrumRadioGroupControl: ComponentType<OwnPropsOfControl & OwnPropsOfEnum>;

export declare const SpectrumRadioGroupControlTester: RankedTester;

declare const SpectrumRatingCell: (props: CellProps & SpectrumInputProps) => JSX_2.Element;

export declare const SpectrumRatingControl: ComponentType<OwnPropsOfControl>;

export declare const SpectrumRatingControlTester: RankedTester;

export declare const SpectrumRenderers: {
    tester: RankedTester;
    renderer: any;
}[];

export declare const SpectrumSliderCell: ComponentType<OwnPropsOfCell>;

declare const SpectrumSliderCell_2: (props: CellProps & SpectrumInputProps) => JSX_2.Element;

export declare const SpectrumSliderCellTester: RankedTester;

export declare const SpectrumSliderControl: ComponentType<OwnPropsOfControl>;

export declare const SpectrumSliderControlTester: RankedTester;

export declare const SpectrumSwitchCell: ComponentType<OwnPropsOfCell>;

declare const SpectrumSwitchCell_2: (props: CellProps & SpectrumInputProps) => JSX_2.Element;

/**
 * Default tester for Switch controls.
 * @type {RankedTester}
 */
export declare const SpectrumSwitchCellTester: RankedTester;

export declare const SpectrumSwitchControl: ComponentType<OwnPropsOfControl>;

export declare const SpectrumSwitchControlTester: RankedTester;

export declare const SpectrumTextAndButtonControl: ComponentType<OwnPropsOfControl>;

export declare const SpectrumTextAndButtonControlTester: RankedTester;

export declare const SpectrumTextAreaCell: ComponentType<OwnPropsOfCell>;

declare const SpectrumTextAreaCell_2: (props: CellProps & SpectrumInputProps) => JSX_2.Element;

/**
 * Tester for a multi-line string control.
 * @type {RankedTester}
 */
export declare const SpectrumTextAreaCellTester: RankedTester;

export declare const SpectrumTextAreaControl: ComponentType<OwnPropsOfControl>;

export declare const SpectrumTextAreaControlTester: RankedTester;

export declare const SpectrumTextCell: ComponentType<OwnPropsOfCell>;

declare const SpectrumTextCell_2: (props: CellProps & SpectrumInputProps) => JSX_2.Element;

/**
 * Default tester for text-based/string controls.
 * @type {RankedTester}
 */
export declare const SpectrumTextCellTester: RankedTester;

export declare const SpectrumTextControl: ComponentType<OwnPropsOfControl>;

export declare const SpectrumTextControlTester: RankedTester;

export declare const SpectrumTimeControl: ComponentType<OwnPropsOfControl>;

export declare const SpectrumTimeControlTester: RankedTester;

export declare const SpectrumTipTapRenderer: ComponentType<OwnPropsOfControl>;

export declare const SpectrumTipTapRendererTester: RankedTester;

export declare const SpectrumVerticalLayout: ComponentType<LayoutProps & OwnPropsOfLayout>;

/**
 * Default tester for a vertical layout.
 * @type {RankedTester}
 */
export declare const SpectrumVerticalLayoutTester: RankedTester;

export declare const useBreadcrumbs: () => BreadcrumbsContextType;

export declare const useDebouncedChange: (handleChange: (path: string, value: any) => void, defaultValue: any, data: any, path: string) => [any, (value: any) => void, () => void];

export declare const useFocus: () => [boolean, () => void, () => void];

export declare const useRenderersConfig: () => RenderersConfigContextType;

export declare const valueErrorMessage: (minValue: any, maxValue: any) => string | undefined;

export declare const withAjvProps: <P extends {}>(Component: React_2.ComponentType<AjvProps & P>) => (props: P) => JSX_2.Element;

export declare const withHandleChange: <P extends {}>(Component: React_2.ComponentType<P & DispatchPropsOfControl>) => (props: P) => JSX_2.Element;

export declare const withJsonFormsArrayControlProps: (Component: React_2.ComponentType<ArrayControlProps>, memoize?: boolean) => React_2.ComponentType<OwnPropsOfControl>;

export { }
